package Mojolicious::Plugin::AttributeMaker::Extension;
use strict;
use warnings;
#Base class :)
#Infected by Mojolicious::Plugin::Router;
=head1 NAME

Mojolicious::Plugin::AttributeMaker::Extension - Base class for extending AttributeMaker functionality

=cut

1;